.\" dpkg manual page - dpkg-deb(1)
.\"
.\" Copyright © 1995-1996 Ian Jackson <ijackson@chiark.greenend.org.uk>
.\" Copyright © 2000 Wichert Akkerman <wakkerma@debian.org>
.\" Copyright © 2006 Frank Lichtenheld <djpig@debian.org>
.\" Copyright © 2007-2011 Raphaël Hertzog <hertzog@debian.org>
.\" Copyright © 2011-2013, 2015 Guillem Jover <guillem@debian.org>
.\"
.\" This is free software; you can redistribute it and/or modify
.\" it under the terms of the GNU General Public License as published by
.\" the Free Software Foundation; either version 2 of the License, or
.\" (at your option) any later version.
.\"
.\" This is distributed in the hope that it will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with this program.  If not, see <https://www.gnu.org/licenses/>.
.
.\"*******************************************************************
.\"
.\" This file was generated with po4a. Translate the source file.
.\"
.\"*******************************************************************
.TH dpkg\-shlibdeps 1 %RELEASE_DATE% %VERSION% "dpkg készlet"
.ad l
.nh
.SH NÉV
dpkg\-shlibdeps \- generate shared library substvar dependencies
.
.SH SZINOPSZIS
\fBdpkg\-shlibdeps\fP [\fIoption\fP...] [\fB\-e\fP]\fIexecutable\fP [\fIoption\fP...]
.
.SH LEÍRÁS
\fBdpkg\-shlibdeps\fP calculates shared library dependencies for executables
named in its arguments. The dependencies are added to the substitution
variables file \fBdebian/substvars\fP as variable names
\fBshlibs:\fP\fIdependency\-field\fP where \fIdependency\-field\fP is a dependency
field name. Any other variables starting with \fBshlibs:\fP are removed from
the file.
.P
\fBdpkg\-shlibdeps\fP has two possible sources of information to generate
dependency information. Either \fIsymbols\fP files or \fIshlibs\fP files. For each
binary that \fBdpkg\-shlibdeps\fP analyzes, it finds out the list of libraries
that it's linked with.  Then, for each library, it looks up either the
\fIsymbols\fP file, or the \fIshlibs\fP file (if the former doesn't exist or if
debian/shlibs.local contains the relevant dependency). Both files are
supposed to be provided by the library package and should thus be available
as %ADMINDIR%/info/\fIpackage\fP.\fIsymbols\fP or
%ADMINDIR%/info/\fIpackage\fP.\fIshlibs\fP. The package name is identified in two
steps: find the library file on the system (looking in the same directories
that \fBld.so\fP would use), then use \fBdpkg \-S \fP\fIlibrary\-file\fP to lookup the
package providing the library.
.SS "Symbols files"
Symbols files contain finer\-grained dependency information by providing the
minimum dependency for each symbol that the library exports. The script
tries to find a symbols file associated to a library package in the
following places (first match is used):
.IP debian/*/DEBIAN/symbols
Shared library information generated by the current build process that also
invoked \fBdpkg\-shlibdeps\fP.  They are generated by \fBdpkg\-gensymbols\fP(1).
They are only used if the library is found in a package's build tree. The
symbols file in that build tree takes precedence over symbols files from
other binary packages.
.IP %PKGCONFDIR%/symbols/\fIpackage\fP.symbols.\fIarch\fP
.IP %PKGCONFDIR%/symbols/\fIpackage\fP.symbols
Per\-system overriding shared library dependency information.  \fIarch\fP is the
architecture of the current system (obtained by \fBdpkg\-architecture
\-qDEB_HOST_ARCH\fP).
.IP "Output from “\fBdpkg\-query \-\-control\-path\fP \fIpackage\fP symbols”"
Package\-provided shared library dependency information.  Unless overridden
by \fB\-\-admindir\fP, those files are located in %ADMINDIR%.
.P
While scanning the symbols used by all binaries, \fBdpkg\-shlibdeps\fP remembers
the (biggest) minimal version needed for each library. At the end of the
process, it is able to write out the minimal dependency for every library
used (provided that the information of the \fIsymbols\fP files are accurate).
.P
As a safe\-guard measure, a symbols file can provide a
\fBBuild\-Depends\-Package\fP meta\-information field and \fBdpkg\-shlibdeps\fP will
extract the minimal version required by the corresponding package in the
\fBBuild\-Depends\fP field and use this version if it's higher than the minimal
version computed by scanning symbols.
.SS "Shlibs files"
Shlibs files associate directly a library to a dependency (without looking
at the symbols). It's thus often stronger than really needed but very safe
and easy to handle.
.P
The dependencies for a library are looked up in several places. The first
file providing information for the library of interest is used:
.IP debian/shlibs.local
Package\-local overriding shared library dependency information.
.IP %PKGCONFDIR%/shlibs.override
Per\-system overriding shared library dependency information.
.IP debian/*/DEBIAN/shlibs
Shared library information generated by the current build process that also
invoked \fBdpkg\-shlibdeps\fP.  They are only used if the library is found in a
package's build tree. The shlibs file in that build tree takes precedence
over shlibs files from other binary packages.
.IP "Output from “\fBdpkg\-query \-\-control\-path\fP \fIpackage\fP shlibs”"
Package\-provided shared library dependency information.  Unless overridden
by \fB\-\-admindir\fP, those files are located in %ADMINDIR%.
.IP %PKGCONFDIR%/shlibs.default
Per\-system default shared library dependency information.
.P
The extracted dependencies are then directly used (except if they are
filtered out because they have been identified as duplicate, or as weaker
than another dependency).
.SH OPTIONS
\fBdpkg\-shlibdeps\fP interprets non\-option arguments as executable names, just
as if they'd been supplied as \fB\-e\fP\fIexecutable\fP.
.TP 
\fB\-e\fP\fIexecutable\fP
Include dependencies appropriate for the shared libraries required by
\fIexecutable\fP.  This option can be used multiple times.
.TP 
\fB\-l\fP\fIdirectory\fP
Prepend \fIdirectory\fP to the list of directories to search for private shared
libraries (since dpkg 1.17.0). This option can be used multiple times.

Note: Use this option instead of setting \fBLD_LIBRARY_PATH\fP, as that
environment variable is used to control the run\-time linker and abusing it
to set the shared library paths at build\-time can be problematic when
cross\-compiling for example.
.TP 
\fB\-d\fP\fIdependency\-field\fP
Add dependencies to be added to the control file dependency field
\fIdependency\-field\fP.  (The dependencies for this field are placed in the
variable \fBshlibs:\fP\fIdependency\-field\fP.)

The \fB\-d\fP\fIdependency\-field\fP option takes effect for all executables after
the option, until the next \fB\-d\fP\fIdependency\-field\fP.  The default
\fIdependency\-field\fP is \fBDepends\fP.

If the same dependency entry (or set of alternatives) appears in more than
one of the recognized dependency field names \fBPre\-Depends\fP, \fBDepends\fP,
\fBRecommends\fP, \fBEnhances\fP or \fBSuggests\fP then \fBdpkg\-shlibdeps\fP will
automatically remove the dependency from all fields except the one
representing the most important dependencies.
.TP 
\fB\-p\fP\fIvarname\-prefix\fP
Start substitution variables with \fIvarname\-prefix\fP\fB:\fP instead of
\fBshlibs:\fP.  Likewise, any existing substitution variables starting with
\fIvarname\-prefix\fP\fB:\fP (rather than \fBshlibs:\fP)  are removed from the
substitution variables file.
.TP 
\fB\-O\fP[\fIfilename\fP]
Print substitution variable settings to standard output (or \fIfilename\fP if
specified, since dpkg 1.17.2), rather than being added to the substitution
variables file (\fBdebian/substvars\fP by default).
.TP 
\fB\-t\fP\fItype\fP
Prefer shared library dependency information tagged for the given package
type. If no tagged information is available, falls back to untagged
information. The default package type is \fBdeb\fP. Shared library dependency
information is tagged for a given type by prefixing it with the name of the
type, a colon, and whitespace.
.TP 
\fB\-L\fP\fIlocal\-shlibs\-file\fP
Read overriding shared library dependency information from
\fIlocal\-shlibs\-file\fP instead of \fBdebian/shlibs.local\fP.
.TP 
\fB\-T\fP\fIsubstvars\-file\fP
Write substitution variables in \fIsubstvars\-file\fP; the default is
\fBdebian/substvars\fP.
.TP 
\fB\-v\fP
Enable verbose mode (since dpkg 1.14.8).  Numerous messages are displayed to
explain what \fBdpkg\-shlibdeps\fP does.
.TP 
\fB\-x\fP\fIpackage\fP
Exclude the package from the generated dependencies (since dpkg 1.14.8).
This is useful to avoid self\-dependencies for packages which provide ELF
binaries (executables or library plugins) using a library contained in the
same package. This option can be used multiple times to exclude several
packages.
.TP 
\fB\-S\fP\fIpackage\-build\-dir\fP
Look into \fIpackage\-build\-dir\fP first when trying to find a library (since
dpkg 1.14.15).  This is useful when the source package builds multiple
flavors of the same library and you want to ensure that you get the
dependency from a given binary package. You can use this option multiple
times: directories will be tried in the same order before directories of
other binary packages.
.TP 
\fB\-I\fP\fIpackage\-build\-dir\fP
Ignore \fIpackage\-build\-dir\fP when looking for shlibs, symbols, and shared
library files (since dpkg 1.18.5).  You can use this option multiple times.
.TP 
\fB\-\-ignore\-missing\-info\fP
Do not fail if dependency information can't be found for a shared library
(since dpkg 1.14.8).  Usage of this option is discouraged, all libraries
should provide dependency information (either with shlibs files, or with
symbols files)  even if they are not yet used by other packages.
.TP 
\fB\-\-warnings=\fP\fIvalue\fP
\fIvalue\fP is a bit field defining the set of warnings that can be emitted by
\fBdpkg\-shlibdeps\fP (since dpkg 1.14.17).  Bit 0 (value=1) enables the warning
“symbol \fIsym\fP used by \fIbinary\fP found in none of the libraries”, bit 1
(value=2) enables the warning “package could avoid a useless dependency” and
bit 2 (value=4) enables the warning “\fIbinary\fP should not be linked against
\fIlibrary\fP”.  The default \fIvalue\fP is 3: the first two warnings are active
by default, the last one is not. Set \fIvalue\fP to 7 if you want all warnings
to be active.
.TP 
\fB\-\-admindir=\fP\fIdir\fP
Change the location of the \fBdpkg\fP database (since dpkg 1.14.0).  The
default location is \fI%ADMINDIR%\fP.
.TP 
\fB\-?\fP, \fB\-\-help\fP
Show the usage message and exit.
.TP 
\fB\-\-version\fP
Show the version and exit.
.
.SH ENVIRONMENT
.TP 
\fBDPKG_COLORS\fP
Sets the color mode (since dpkg 1.18.5).  The currently accepted values are:
\fBauto\fP (default), \fBalways\fP and \fBnever\fP.
.TP 
\fBDPKG_NLS\fP
If set, it will be used to decide whether to activate Native Language
Support, also known as internationalization (or i18n) support (since dpkg
1.19.0).  The accepted values are: \fB0\fP and \fB1\fP (default).
.
.SH DIAGNOSTICS
.SS Warnings
Since \fBdpkg\-shlibdeps\fP analyzes the set of symbols used by each binary of
the generated package, it is able to emit warnings in several cases. They
inform you of things that can be improved in the package. In most cases,
those improvements concern the upstream sources directly. By order of
decreasing importance, here are the various warnings that you can encounter:
.TP 
\fBsymbol\fP\fI sym\fP\fB used by \fP\fIbinary\fP\fB found in none of the libraries.\fP
The indicated symbol has not been found in the libraries linked with the
binary. The \fIbinary\fP is most likely a library and it needs to be linked
with an additional library during the build process (option \fB\-l\fP\fIlibrary\fP
of the linker).
.TP 
\fIbinary\fP\fB contains an unresolvable reference to symbol \fP\fIsym\fP\fB: it's probably a plugin\fP
The indicated symbol has not been found in the libraries linked with the
binary. The \fIbinary\fP is most likely a plugin and the symbol is probably
provided by the program that loads this plugin. In theory a plugin doesn't
have any SONAME but this binary does have one and as such it could not be
clearly identified as such. However the fact that the binary is stored in a
non\-public directory is a strong indication that's it's not a normal shared
library. If the binary is really a plugin, then disregard this warning. But
there's always the possibility that it's a real library and that programs
linking to it are using an RPATH so that the dynamic loader finds it. In
that case, the library is broken and needs to be fixed.
.TP 
\fBpackage could avoid a useless dependency if \fP\fIbinary\fP\fB was not linked against \fP\fIlibrary\fP\fB (it uses none of the library's symbols)\fP
None of the \fIbinaries\fP that are linked with \fIlibrary\fP use any of the
symbols provided by the library. By fixing all the binaries, you would avoid
the dependency associated to this library (unless the same dependency is
also generated by another library that is really used).
.TP 
\fBpackage could avoid a useless dependency if \fP\fIbinaries\fP\fB were not linked against \fP\fIlibrary\fP\fB (they use none of the library's symbols)\fP
Exactly the same as the above warning, but for multiple binaries.
.TP 
\fIbinary\fP\fB should not be linked against \fP\fIlibrary\fP\fB (it uses none of the library's symbols)\fP
The \fIbinary\fP is linked to a library that it doesn't need. It's not a
problem but some small performance improvements in binary load time can be
obtained by not linking this library to this binary. This warning checks the
same information as the previous one but does it for each binary instead of
doing the check globally on all binaries analyzed.
.SS Errors
\fBdpkg\-shlibdeps\fP will fail if it can't find a public library used by a
binary or if this library has no associated dependency information (either
shlibs file or symbols file). A public library has a SONAME and is versioned
(libsomething.so.\fIX\fP). A private library (like a plugin) should not have a
SONAME and doesn't need to be versioned.
.TP 
\fBcouldn't find library \fP\fIlibrary\-soname\fP\fB needed by \fP\fIbinary\fP\fB (its RPATH is '\fP\fIrpath\fP\fB')\fP
The \fIbinary\fP uses a library called \fIlibrary\-soname\fP but \fBdpkg\-shlibdeps\fP
has been unable to find the library.  \fBdpkg\-shlibdeps\fP creates a list of
directories to check as following: directories listed in the RPATH of the
binary, directories added by the \fB\-l\fP option, directories listed in the
\fBLD_LIBRARY_PATH\fP environment variable, cross multiarch directories
(ex. /lib/arm64\-linux\-gnu, /usr/lib/arm64\-linux\-gnu), standard public
directories (/lib, /usr/lib), directories listed in /etc/ld.so.conf, and
obsolete multilib directories (/lib32, /usr/lib32, /lib64, /usr/lib64).
Then it checks those directories in the package's build tree of the binary
being analyzed, in the packages' build trees indicated with the \fB\-S\fP
command\-line option, in other packages' build trees that contains a
DEBIAN/shlibs or DEBIAN/symbols file and finally in the root directory.  If
the library is not found in any of those directories, then you get this
error.

If the library not found is in a private directory of the same package, then
you want to add the directory with \fB\-l\fP. If it's in another binary package
being built, you want to make sure that the shlibs/symbols file of this
package is already created and that \fB\-l\fP contains the appropriate directory
if it also is in a private directory.
.TP 
\fBno dependency information found for \fP\fIlibrary\-file\fP\fB (used by \fP\fIbinary\fP\fB).\fP
The library needed by \fIbinary\fP has been found by \fBdpkg\-shlibdeps\fP in
\fIlibrary\-file\fP but \fBdpkg\-shlibdeps\fP has been unable to find any dependency
information for that library. To find out the dependency, it has tried to
map the library to a Debian package with the help of \fBdpkg \-S
\fP\fIlibrary\-file\fP.  Then it checked the corresponding shlibs and symbols
files in %ADMINDIR%/info/, and in the various package's build trees
(debian/*/DEBIAN/).

This failure can be caused by a bad or missing shlibs or symbols file in the
package of the library. It might also happen if the library is built within
the same source package and if the shlibs files has not yet been created (in
which case you must fix debian/rules to create the shlibs before calling
\fBdpkg\-shlibdeps\fP). Bad RPATH can also lead to the library being found under
a non\-canonical name (example:
/usr/lib/openoffice.org/../lib/libssl.so.0.9.8 instead of
/usr/lib/libssl.so.0.9.8) that's not associated to any package,
\fBdpkg\-shlibdeps\fP tries to work around this by trying to fallback on a
canonical name (using \fBrealpath\fP(3))  but it might not always work. It's
always best to clean up the RPATH of the binary to avoid problems.

Calling \fBdpkg\-shlibdeps\fP in verbose mode (\fB\-v\fP) will provide much more
information about where it tried to find the dependency information. This
might be useful if you don't understand why it's giving you this error.
.SH "LÁSD MÉG"
\fBdeb\-shlibs\fP(5), \fBdeb\-symbols\fP(5), \fBdpkg\-gensymbols\fP(1).
