.\" dpkg manual page - dpkg-split(1)
.\"
.\" Copyright © 1995-1996 Ian Jackson <ijackson@chiark.greenend.org.uk>
.\" Copyright © 2011 Guillem Jover <guillem@debian.org>
.\"
.\" This is free software; you can redistribute it and/or modify
.\" it under the terms of the GNU General Public License as published by
.\" the Free Software Foundation; either version 2 of the License, or
.\" (at your option) any later version.
.\"
.\" This is distributed in the hope that it will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with this program.  If not, see <https://www.gnu.org/licenses/>.
.
.\"*******************************************************************
.\"
.\" This file was generated with po4a. Translate the source file.
.\"
.\"*******************************************************************
.TH dpkg\-split 1 %RELEASE_DATE% %VERSION% "dpkg suite"
.ad l
.nh
.SH NOME
dpkg\-split \- Debian package archive split/join tool
.
.SH RESUMO
\fBdpkg\-split\fP [\fIoption\fP...] \fIcommand\fP
.
.SH DESCRIÇÃO
\fBdpkg\-split\fP splits Debian binary package files into smaller parts and
reassembles them again, to support the storage of large package files on
small media such as floppy disks.

It can be operated manually using the \fB\-\-split\fP, \fB\-\-join\fP and \fB\-\-info\fP
options.

It also has an automatic mode, invoked using the \fB\-\-auto\fP option, where it
maintains a queue of parts seen but not yet reassembled and reassembles a
package file when it has seen all of its parts. The \fB\-\-listq\fP and
\fB\-\-discard\fP options allow the management of the queue.

All splitting, joining and queueing operations produce informative messages
on standard output; these may safely be ignored.
.
.SH COMMANDS
.TP 
\fB\-s\fP, \fB\-\-split\fP \fIcomplete\-archive\fP [\fIprefix\fP]
Splits a single Debian binary package into several parts.

The parts are named \fIprefix\fP\fB.\fP\fIN\fP\fBof\fP\fIM\fP\fB.deb\fP where \fIN\fP is the part
number, starting at 1, and \fIM\fP is the total number of parts (both in
decimal).

If no \fIprefix\fP is supplied then the \fIcomplete\-archive\fP filename is taken,
including directory, with any trailing \fB.deb\fP removed.
.TP 
\fB\-j\fP, \fB\-\-join\fP \fIpart\fP...
Joins the parts of a package file together, reassembling the original file
as it was before it was split.

The part files given as arguments must be all the parts of exactly the same
original binary file. Each part must occur exactly once in the argument
list, though the parts to not need to be listed in order.

The parts must of course all have been generated with the same part size
specified at split time, which means that they must usually have been
generated by the same invocation of \fBdpkg\-split \-\-split\fP.

The parts' filenames are not significant for the reassembly process.

By default the output file is called
\fIpackage\fP\fB_\fP\fIversion\fP\fB_\fP\fIarch\fP\fB.deb\fP.

.TP 
\fB\-I\fP, \fB\-\-info\fP \fIpart\fP...
Prints information, in a human\-readable format, about the part file(s)
specified. Arguments which are not binary package parts produce a message
saying so instead (but still on standard output).
.TP 
\fB\-a\fP, \fB\-\-auto \-o\fP \fIcomplete\-output part\fP
Automatically queue parts and reassemble a package if possible.

The \fIpart\fP specified is examined, and compared with other parts of the same
package (if any) in the queue of packages file parts.

If all parts of the package file of which \fIpart\fP is a part are available
then the package is reassembled and written to \fIcomplete\-output\fP (which
should not usually already exist, though this is not an error).

If not then the \fIpart\fP is copied into the queue and \fIcomplete\-output\fP is
not created.

If \fIpart\fP is not a split binary package part then \fBdpkg\-split\fP will exit
with status \fB1\fP; if some other trouble occurs then it will exit with status
\fB2\fP.

The \fB\-\-output\fP or \fB\-o\fP option must be supplied when using \fB\-\-auto\fP.  (If
this were not mandatory the calling program would not know what output file
to expect.)
.TP 
\fB\-l\fP, \fB\-\-listq\fP
Lists the contents of the queue of packages to be reassembled.

For each package file of which parts are in the queue the output gives the
name of the package, the parts in the queue, and the total number of bytes
stored in the queue.
.TP 
\fB\-d\fP, \fB\-\-discard\fP [\fIpackage\fP...]
This discards parts from the queue of those waiting for the remaining parts
of their packages.

If no \fIpackage\fP is specified then the queue is cleared completely; if any
are specified then only parts of the relevant package(s) are deleted.
.TP 
\fB\-?\fP, \fB\-\-help\fP
Show the usage message and exit.
.TP 
\fB\-\-version\fP
Show the version and exit.
.
.SH OPÇÕES
.TP 
\fB\-\-depotdir\fP\fI directory\fP
Specifies an alternative directory for the queue of parts awaiting automatic
reassembly. The default is \fB%ADMINDIR%\fP.
.TP 
\fB\-S\fP, \fB\-\-partsize\fP \fIkibibytes\fP
Specifies the maximum part size when splitting, in kibibytes (1024
bytes). The default is 450 KiB.
.TP 
\fB\-o\fP, \fB\-\-output\fP \fIcomplete\-output\fP
Specifies the output file name for a reassembly.

This overrides the default for a manual reassembly (\fB\-\-join\fP)  and is
mandatory for an automatic queue\-or\-reassemble (\fB\-\-auto\fP).
.TP 
\fB\-Q\fP, \fB\-\-npquiet\fP
When doing automatic queue\-or\-reassembly \fBdpkg\-split\fP usually prints a
message if it is given a \fIpart\fP that is not a binary package part. This
option suppresses this message, to allow programs such as \fBdpkg\fP to cope
with both split and unsplit packages without producing spurious messages.
.TP 
\fB\-\-msdos\fP
Forces the output filenames generated by \fB\-\-split\fP to be msdos\-compatible.

This mangles the prefix \- either the default derived from the input filename
or the one supplied as an argument: alphanumerics are lowercased, plus signs
are replaced by \fBx\fP's and all other characters are discarded.

The result is then truncated as much as is necessary, and filenames of the
form \fIprefixN\fP\fBof\fP\fIM\fP\fB.deb\fP are generated.
.
.SH "EXIT STATUS"
.TP 
\fB0\fP
The requested split, merge, or other command succeeded.  \fB\-\-info\fP commands
count as successful even if the files are not binary package parts.
.TP 
\fB1\fP
Only occurs with \fB\-\-auto\fP and indicates that the \fIpart\fP file was not a
binary package part.
.TP 
\fB2\fP
Fatal or unrecoverable error due to invalid command\-line usage, a file that
looked like a package part file but was corrupted, or interactions with the
system, such as accesses to the database, memory allocations, etc.
.
.SH ENVIRONMENT
.TP 
\fBDPKG_COLORS\fP
Sets the color mode (since dpkg 1.18.5).  The currently accepted values are:
\fBauto\fP (default), \fBalways\fP and \fBnever\fP.
.TP 
\fBSOURCE_DATE_EPOCH\fP
If set, it will be used as the timestamp (as seconds since the epoch) in the
\fBdeb\-split\fP(5)'s \fBar\fP(5) container.
.
.SH ARQUIVOS
.TP 
\fI%ADMINDIR%/parts\fP
The default queue directory for part files awaiting automatic reassembly.

The filenames used in this directory are in a format internal to
\fBdpkg\-split\fP and are unlikely to be useful to other programs, and in any
case the filename format should not be relied upon.
.
.SH BUGS
Full details of the packages in the queue are impossible to get without
digging into the queue directory yourself.

There is no easy way to test whether a file that may be a binary package
part is one.
.
.SH "VEJA TAMBÉM"
\fBdeb\fP(5), \fBdeb\-control\fP(5), \fBdpkg\-deb\fP(1), \fBdpkg\fP(1).
